@@ -2,7 +2,7 @@ use crate::mutations::*;
 use holo_hash::HasHash;
 use holochain_sqlite::rusqlite::Transaction;
 use holochain_types::dht_op::DhtOpHashed;
-use holochain_types::timestamp;
+use holochain_zome_types::Timestamp;
 
 pub fn insert_valid_authored_op(txn: &mut Transaction, op: DhtOpHashed) -> StateMutationResult<()> {
     let hash = op.as_hash().clone();
@@ -23,7 +23,7 @@ pub fn insert_valid_integrated_op(
         hash.clone(),
         holochain_zome_types::ValidationStatus::Valid,
     )?;
-    set_when_integrated(txn, hash, timestamp::now())?;
+    set_when_integrated(txn, hash, Timestamp::now())?;
 
     Ok(())
 }
